==> qcad-3.5.1.0_2.txz: usr/local/share/qcad/scripts/Widgets/CadToolBar/ts/CadToolBar_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>CadToolBar</name>
    <message>
        <source>16</source>
        <translation type="obsolete">16</translation>
    </message>
    <message>
        <source>32</source>
        <translation type="obsolete">32</translation>
    </message>
    <message>
        <source>64</source>
        <translation type="obsolete">64</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+88"/>
        <source>Pixel</source>
        <translation>Pixel</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>px</source>
        <translation>px</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Columns:</source>
        <translation>Spalten:</translation>
    </message>
    <message>
        <location filename="../CadToolBar.js" line="+49"/>
        <source>Widgets</source>
        <translation>Widgets</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>CAD Toolbar</source>
        <translation>CAD Werkzeugleiste</translation>
    </message>
    <message>
        <location line="+31"/>
        <source>Toggle Title Bar</source>
        <translation>Titelleiste anzeigen</translation>
    </message>
    <message>
        <source>CAD Tool Bar</source>
        <translation type="obsolete">CAD Werkzeugleiste</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="-83"/>
        <source>Icon Size:</source>
        <translation>Symbolgrösse:</translation>
    </message>
    <message>
        <source>24</source>
        <translation type="obsolete">24</translation>
    </message>
    <message>
        <source>28</source>
        <translation type="obsolete">28</translation>
    </message>
    <message>
        <source>40</source>
        <translation type="obsolete">40</translation>
    </message>
    <message>
        <source>48</source>
        <translation type="obsolete">48</translation>
    </message>
    <message>
        <source>80</source>
        <translation type="obsolete">80</translation>
    </message>
    <message>
        <source>96</source>
        <translation type="obsolete">96</translation>
    </message>
    <message>
        <source>112</source>
        <translation type="obsolete">112</translation>
    </message>
    <message>
        <source>128</source>
        <translation type="obsolete">128</translation>
    </message>
</context>
<context>
    <name>CadToolBarPanel</name>
    <message>
        <location filename="../CadToolBarPanel.js" line="+76"/>
        <source>Back</source>
        <translation>Zurück</translation>
    </message>
</context>
</TS>

==> qcad-3.15.2.0.txz: usr/local/share/qcad/scripts/Widgets/CadToolBar/ts/CadToolBar_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>CadToolBar</name>
    <message>
        <source>16</source>
        <translation type="obsolete">16</translation>
    </message>
    <message>
        <source>32</source>
        <translation type="obsolete">32</translation>
    </message>
    <message>
        <source>64</source>
        <translation type="obsolete">64</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+88"/>
        <source>Pixel</source>
        <translation>Pixel</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>px</source>
        <translation>px</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Columns:</source>
        <translation>Spalten:</translation>
    </message>
    <message>
        <location filename="../CadToolBar.js" line="+51"/>
        <source>Widgets</source>
        <translation>Widgets</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>CAD Toolbar</source>
        <translation>CAD Werkzeugleiste</translation>
    </message>
    <message>
        <location line="+35"/>
        <source>Vertical/Horizontal</source>
        <translation>Vertikal / Horizontal</translation>
    </message>
    <message>
        <source>Toggle Title Bar</source>
        <translation type="vanished">Titelleiste anzeigen</translation>
    </message>
    <message>
        <source>CAD Tool Bar</source>
        <translation type="obsolete">CAD Werkzeugleiste</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="-83"/>
        <source>Icon Size:</source>
        <translation>Symbolgrösse:</translation>
    </message>
    <message>
        <source>24</source>
        <translation type="obsolete">24</translation>
    </message>
    <message>
        <source>28</source>
        <translation type="obsolete">28</translation>
    </message>
    <message>
        <source>40</source>
        <translation type="obsolete">40</translation>
    </message>
    <message>
        <source>48</source>
        <translation type="obsolete">48</translation>
    </message>
    <message>
        <source>80</source>
        <translation type="obsolete">80</translation>
    </message>
    <message>
        <source>96</source>
        <translation type="obsolete">96</translation>
    </message>
    <message>
        <source>112</source>
        <translation type="obsolete">112</translation>
    </message>
    <message>
        <source>128</source>
        <translation type="obsolete">128</translation>
    </message>
</context>
<context>
    <name>CadToolBarPanel</name>
    <message>
        <location filename="../CadToolBarPanel.js" line="+107"/>
        <source>Back</source>
        <translation>Zurück</translation>
    </message>
</context>
</TS>
